==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/model/FileuploadModel.java <==
package com.hippoagent.model;

import com.hippoagent.utils.Log;
import org.json.JSONObject;

import java.util.ArrayList;

/**
 * Created by gurmail on 16/01/19.
 *
 * @author gurmail
 */
public class FileuploadModel {

    String fileName;
    String fileSize;
    String fileSizeReadable;
    String fileMime;
    String muid;
    int messageType;
    String documentType;
    ArrayList<Integer> dimns = new ArrayList<>();
    int messageIndex;
    boolean fileUploaded;
    int channelId;
    JSONObject messageObject;
    Long labelId;
    String filePath;

    public Long getLabelId() {
        return labelId;
    }

    public void setLabelId(Long labelId) {
        this.labelId = labelId;
    }

    public boolean isFileUploaded() {
        return fileUploaded;
    }

    public void setFileUploaded(boolean fileUploaded) {
        this.fileUploaded = fileUploaded;
    }

    public int getChannelId() {
        return channelId;
    }

    public void setChannelId(int channelId) {
        this.channelId = channelId;
    }

    public JSONObject getMessageObject() {
        return messageObject;
    }

    public void setMessageObject(JSONObject messageObject) {
        this.messageObject = messageObject;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public void setFileSize(String fileSize) {
        this.fileSize = fileSize;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }


    public ArrayList<Integer> getDimns() {
        return dimns;
    }

    public void setDimns(ArrayList<Integer> dimns) {
        this.dimns = dimns;
    }

    public int getMessageType() {
        return messageType;
    }

    public void setMessageType(int messageType) {
        this.messageType = messageType;
    }

    public String getDocumentType() {
        return documentType;
    }

    public void setDocumentType(String documentType) {
        this.documentType = documentType;
    }

    public String getFileMime() {
        return fileMime;
    }

    public void setFileMime(String fileMime) {
        this.fileMime = fileMime;
    }

    public String getMuid() {
        return muid;
    }

    public void setMuid(String muid) {
        this.muid = muid;
    }

    public int getMessageIndex() {
        return messageIndex;
    }

    public void setMessageIndex(int messageIndex) {
        this.messageIndex = messageIndex;
    }

    public String getFileName() {
        return fileName;
    }

    public String getFileSize() {
        return fileSize;
    }

    public String getFilePath() {
        return filePath;
    }

    public FileuploadModel(int channelId) {
        this.channelId = channelId;
    }


    public String getFileSizeReadable() {
        return fileSizeReadable;
    }

    public void setFileSizeReadable(String fileSizeReadable) {
        this.fileSizeReadable = fileSizeReadable;
    }

    public FileuploadModel(String fileName, String fileSize, String filePath, String muid) {
        this.fileName = fileName;
        this.filePath = filePath;
        this.fileSize = fileSize;
        this.muid = muid;
    }

    @Override
    public boolean equals(Object obj) {
        try {
            Log.v("tag", "((FileuploadModel) obj).getChannelId() = "+((FileuploadModel) obj).getChannelId());
            Log.v("tag", "getChannelId()" + getChannelId());
            return ((FileuploadModel) obj).getChannelId() == getChannelId();
        } catch (Exception e) {
            return false;
        }
    }
}

==> hippoagentsdk-3.0.5.1-sources.jar: com/hippoagent/model/FileuploadModel.java <==
package com.hippoagent.model;

import com.hippoagent.utils.Log;
import org.json.JSONObject;

import java.util.ArrayList;

/**
 * Created by gurmail on 16/01/19.
 *
 * @author gurmail
 */
public class FileuploadModel {

    String fileName;
    String fileSize;
    String fileSizeReadable;
    String fileMime;
    String muid;
    int messageType;
    String documentType;
    ArrayList<Integer> dimns = new ArrayList<>();
    int messageIndex;
    boolean fileUploaded;
    int channelId;
    JSONObject messageObject;
    Long labelId;
    String filePath;
    boolean isChat = true;

    public void setIsChat(boolean ischat) {
        this.isChat = ischat;
    }

    public boolean isChat() {
        return isChat;
    }

    public Long getLabelId() {
        return labelId;
    }

    public void setLabelId(Long labelId) {
        this.labelId = labelId;
    }

    public boolean isFileUploaded() {
        return fileUploaded;
    }

    public void setFileUploaded(boolean fileUploaded) {
        this.fileUploaded = fileUploaded;
    }

    public int getChannelId() {
        return channelId;
    }

    public void setChannelId(int channelId) {
        this.channelId = channelId;
    }

    public JSONObject getMessageObject() {
        return messageObject;
    }

    public void setMessageObject(JSONObject messageObject) {
        this.messageObject = messageObject;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public void setFileSize(String fileSize) {
        this.fileSize = fileSize;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }


    public ArrayList<Integer> getDimns() {
        return dimns;
    }

    public void setDimns(ArrayList<Integer> dimns) {
        this.dimns = dimns;
    }

    public int getMessageType() {
        return messageType;
    }

    public void setMessageType(int messageType) {
        this.messageType = messageType;
    }

    public String getDocumentType() {
        return documentType;
    }

    public void setDocumentType(String documentType) {
        this.documentType = documentType;
    }

    public String getFileMime() {
        return fileMime;
    }

    public void setFileMime(String fileMime) {
        this.fileMime = fileMime;
    }

    public String getMuid() {
        return muid;
    }

    public void setMuid(String muid) {
        this.muid = muid;
    }

    public int getMessageIndex() {
        return messageIndex;
    }

    public void setMessageIndex(int messageIndex) {
        this.messageIndex = messageIndex;
    }

    public String getFileName() {
        return fileName;
    }

    public String getFileSize() {
        return fileSize;
    }

    public String getFilePath() {
        return filePath;
    }

    public FileuploadModel(int channelId) {
        this.channelId = channelId;
    }


    public String getFileSizeReadable() {
        return fileSizeReadable;
    }

    public void setFileSizeReadable(String fileSizeReadable) {
        this.fileSizeReadable = fileSizeReadable;
    }

    public FileuploadModel(String fileName, String fileSize, String filePath, String muid) {
        this.fileName = fileName;
        this.filePath = filePath;
        this.fileSize = fileSize;
        this.muid = muid;
    }

    @Override
    public boolean equals(Object obj) {
        try {
            Log.v("tag", "((FileuploadModel) obj).getChannelId() = "+((FileuploadModel) obj).getChannelId());
            Log.v("tag", "getChannelId()" + getChannelId());
            return ((FileuploadModel) obj).getChannelId() == getChannelId();
        } catch (Exception e) {
            return false;
        }
    }
}
